Actions, Resources, and Condition Keys for AWS Firewall Manager - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Firewall Manager

AWS Firewall Manager (service prefix: `fms` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- View a list of the API operations available for this service .

Topics

- Actions Defined by AWS Firewall Manager
- Resource Types Defined by AWS Firewall Manager
- Condition Keys for AWS Firewall Manager

## Actions Defined by AWS Firewall Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateAdminAccount | Sets the AWS Firewall Manager administrator account and enables the service in all organization accounts | Write |  |  |
DeleteNotificationChannel | Deletes an AWS Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to notify the FM administrator about major FM events and errors across the organization. | Write |  |  |
DeletePolicy | Permanently deletes an AWS Firewall Manager policy. | Write | policy* |  |
| aws:ResourceTag/${TagKey} |
DisassociateAdminAccount | Disassociates the account that has been set as the AWS Firewall Manager administrator account and and disables the service in all organization accounts | Write |  |  |
GetAdminAccount | Returns the AWS Organizations master account that is associated with AWS Firewall Manager as the AWS Firewall Manager administrator. | Read |  |  |
GetComplianceDetail | Returns detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy. | Read | policy* |  |
GetNotificationChannel | Returns information about the Amazon Simple Notification Service (SNS) topic that is used to record AWS Firewall Manager SNS logs. | Read |  |  |
GetPolicy | Returns information about the specified AWS Firewall Manager policy. | Read | policy* |  |
GetProtectionStatus | Returns policy-level attack summary information in the event of a potential DDoS attack. | Read | policy* |  |
ListComplianceStatus | Returns an array of PolicyComplianceStatus objects in the response. Use PolicyComplianceStatus to get a summary of which member accounts are protected by the specified policy. | List | policy* |  |
ListMemberAccounts | Returns an array of member account ids if the caller is FMS admin account. | List |  |  |
ListPolicies | Returns an array of PolicySummary objects in the response. | List |  |  |
ListTagsForResource | Lists the Tags for a given resource. | Read | policy* |  |
PutNotificationChannel | Designates the IAM role and Amazon Simple Notification Service (SNS) topic that AWS Firewall Manager (FM) could use to notify the FM administrator about major FM events and errors across the organization. | Write |  |  |
PutPolicy | Creates an AWS Firewall Manager policy. | Write | policy* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Adds a Tag to a given resource. | Tagging | policy* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes a Tag from a given resource. | Tagging | policy* |  |
| aws:TagKeys |

## Resource Types Defined by AWS Firewall Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
policy | `arn:$ { Partition}:fms:$ { Region}:$ { Account}:policy/$ { Id}` | aws:ResourceTag/${TagKey}

## Condition Keys for AWS Firewall Manager

AWS Firewall Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters actions based on the allowed set of values for each of the tags | String
aws:ResourceTag/$ { TagKey} | Filters actions based on tag-value assoicated with the resource | String
aws:TagKeys | Filters actions based on the presence of mandatory tags in the request | String